﻿using TestProject.Models;

namespace TestProject;

/// <summary>
/// 동물 검색 핸들러
/// </summary>
public class AnimalSearchHandler : SearchHandler
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Field
    ////////////////////////////////////////////////////////////////////////////////////////// Private

    #region Field

    /// <summary>
    /// 리스트
    /// </summary>
    private List<AnimalModel> list = new List<AnimalModel>
    {
        new AnimalModel { ID = 1, Name = "고양이", Route = "//고양이" },
        new AnimalModel { ID = 2, Name = "개"    , Route = "//개"     },
        new AnimalModel { ID = 3, Name = "원숭이", Route = "//원숭이" },
        new AnimalModel { ID = 4, Name = "코끼리", Route = "//코끼리" },
        new AnimalModel { ID = 5, Name = "곰"    , Route = "//곰"     }
    };

    #endregion

    //////////////////////////////////////////////////////////////////////////////////////////////////// Method
    ////////////////////////////////////////////////////////////////////////////////////////// Protected

    #region 쿼리 변경시 처리하기 - OnQueryChanged(oldValue, newValue)

    /// <summary>
    /// 쿼리 변경시 처리하기
    /// </summary>
    /// <param name="oldValue">이전 값</param>
    /// <param name="newValue">신규 값</param>
    protected override void OnQueryChanged(string oldValue, string newValue)
    {
        base.OnQueryChanged(oldValue, newValue);

        if(string.IsNullOrWhiteSpace(newValue))
        {
            ItemsSource = null;
        }
        else
        {
            ItemsSource = this.list;
        }
    }

    #endregion
    #region 항목 선택시 처리하기 - OnItemSelected(item)

    /// <summary>
    /// 항목 선택시 처리하기
    /// </summary>
    /// <param name="item">항목</param>
    protected override async void OnItemSelected(object item)
    {
        base.OnItemSelected(item);

        AnimalModel animal = item as AnimalModel;

        await Shell.Current.GoToAsync($"{animal.Route}");
    }

    #endregion
}